@@ -697,8 +697,10 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
     env_data_control <- subset(env_data_control, row.names(env_data_control) %in% subset_seq)
     }
 
+
   # NA values are not allowed and must be removed from response data.frame
-  if (sum(is.na(response)) > 0){
+  # exception if cor_na_us accounts for missing values
+  if (sum(is.na(response)) > 0 & !(pcor_na_use %in% c("complete.obs", "na.or.complete", "pairwise.complete.obs"))){
 
     prob_year <- row.names(response[is.na(response), , drop = F])
 
@@ -707,6 +709,7 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
   }
 
+
   # PART 2 - the calculation of day-wise correlations
   # A) fixed window approach
   # B) Variable window approach
@@ -1798,7 +1801,7 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
   # Here, the transfer function is being created
   transfer_data = data.frame(proxy = response[,1], optimized_return =x1[,1])
   lm_model = lm(optimized_return ~ proxy, data = transfer_data)
-  full_range = data.frame(proxy = seq(from = min(response[,1]), to = max(response[,1]), length.out = 100))
+  full_range = data.frame(proxy = seq(from = min(response[,1], na.rm = TRUE), to = max(response[,1], na.rm = TRUE), length.out = 100))
 
   full_range$transfer_f = predict(lm_model, full_range)
 
